@@ -165,14 +165,18 @@ def parse_args(required_config_keys):
 
     args = parser.parse_args()
     if args.config:
+        setattr(args, 'config_path', args.config)
         args.config = load_json(args.config)
     if args.state:
+        setattr(args, 'state_path', args.state)
         args.state = load_json(args.state)
     else:
         args.state = {}
     if args.properties:
+        setattr(args, 'properties_path', args.properties)
         args.properties = load_json(args.properties)
     if args.catalog:
+        setattr(args, 'catalog_path', args.catalog)
         args.catalog = Catalog.load(args.catalog)
 
     check_config(args.config, required_config_keys)
